use crate::{
    types,
    util::{junk, nfl, request},
};

use serenity::builder::{CreateCommand, CreateCommandOption};
use serenity::model::application::{CommandOptionType, ResolvedOption, ResolvedValue};

pub async fn run(options: &[ResolvedOption<'_>]) -> String {
    if let Some(ResolvedOption {
        value: ResolvedValue::String(team),
        ..
    }) = options.first()
    {
        // TODO: get game detail here, like total score, game leaders, play by play, etc.
        String::new()
    } else {
        junk::get_random_insult()
    }
}

pub fn register() -> CreateCommand {
    CreateCommand::new("gamedetail")
        .description("Get the upcoming/current NFL game details given a NFL team such as total score, game leaders, play-by-play, and more")
        .add_option(
            CreateCommandOption::new(CommandOptionType::String, "team", "The team to query")
                .required(true),
        )
}

pub struct GameDetailDiscordResponse {
    pub team_name: String,
    pub record: String,
    pub next_event: String,
    pub game_date: String,
    pub standing: String,
}

impl GameDetailDiscordResponse {
    pub fn format(&self) -> String {
        format!(
            "## {:}\nSeason Record (W-L): {:}\nNext Game: {:}\nNext Game Date: {:}\nStanding: {:}",
            self.team_name, self.record, self.next_event, self.game_date, self.standing
        )
    }
}
