use chrono::prelude::*;
use chrono::DateTime;
use rand::seq::SliceRandom;
use std::collections::HashMap;

pub fn find_team_key(teams: &HashMap<u32, &str>, team_name: &str) -> Option<u32> {
    teams
        .iter()
        .find(|(_k, &v)| v == team_name)
        .map(|(&k, _v)| k)
}

pub fn find_team_name<'a>(teams: &HashMap<u32, &'a str>, identifier: u32) -> Option<&'a str> {
    teams
        .iter()
        .find(|(&k, _v)| k == identifier)
        .map(|(_k, &v)| v)
}

pub fn get_random_insult() -> String {
    let insults = get_insults();
    let result = insults.choose(&mut rand::thread_rng()).unwrap();
    result.to_owned().to_string()
}

fn get_insults<'a>() -> Vec<&'a str> {
    Vec::from([
        "You football bro?",
        "Somebody ought to throw pigskin in your face!",
        "Who are you, Ian?",
        "Your football expertise is about as useful as a screen door on a submarine!",
        "You must think a wide receiver is someone who shovels food into their face!",
    ])
}

pub fn flexible_to_epoch_seconds(time: &str) -> Result<i64, Box<dyn std::error::Error>> {
    let normalized = normalize_rfc_time(time);
    match DateTime::parse_from_rfc3339(&normalized) {
        Ok(dt) => Ok(dt.timestamp()),
        Err(_) => {
            let datetime = if time.ends_with('Z') {
                NaiveDateTime::parse_from_str(&time[..time.len() - 1], "%Y-%m-%dT%H:%M")?
            } else {
                NaiveDateTime::parse_from_str(time, "%Y-%m-%dT%H:%M")?
            };

            Ok(datetime.and_utc().timestamp())
        }
    }
}

fn normalize_rfc_time(time: &str) -> String {
    if time.ends_with('Z') && time.matches(':').count() == 1 {
        let len = time.len();
        format!("{}:00{}", &time[..len - 1], &time[len - 1..])
    } else {
        time.to_string()
    }
}
